@@ -3,10 +3,10 @@ from logging import Logger
 from cloudshell.api.cloudshell_api import ResourceInfo
 
 from cloudshell.iac.terraform.constants import AZURE2G_MODEL, ATTRIBUTE_NAMES, AWS2G_MODEL, CLP_PROVIDER_MODELS, \
-    AWS1G_MODEL, AZURE1G_MODEL
+    AWS1G_MODEL, AZURE1G_MODEL, GCP2G_MODEL
 from cloudshell.iac.terraform.models.shell_helper import ShellHelperObject
 from cloudshell.iac.terraform.services.clp_envvar_handler import AWSCloudProviderEnvVarHandler, \
-    AzureCloudProviderEnvVarHandler
+    AzureCloudProviderEnvVarHandler, GCPCloudProviderEnvVarHandler
 
 
 class ProviderHandler(object):
@@ -53,6 +53,9 @@ class ProviderHandler(object):
         elif clp_res_model in [AZURE1G_MODEL, AZURE2G_MODEL]:
             clp_handler = AzureCloudProviderEnvVarHandler(clp_res_model, clp_resource_attributes, shell_helper)
 
+        elif clp_res_model in [GCP2G_MODEL]:
+            clp_handler = GCPCloudProviderEnvVarHandler(clp_res_model, clp_resource_attributes, shell_helper)
+
         if clp_handler:
             clp_handler.set_env_vars_based_on_clp()
         else:
